@@ -30,6 +30,8 @@
 /*******************************************************************************/
 #include "weather-event.h"
 /*******************************************************************************/
+gboolean not_event = FALSE;
+/*******************************************************************************/
 static GSList *event_time_list = NULL;
 /*******************************************************************************/
 gboolean timer_handler(gpointer data){
@@ -37,7 +39,7 @@ gboolean timer_handler(gpointer data){
     struct event_time *evt;
     time_t current_time;
     int check;
-#ifdef PC_EMULATOR
+#ifndef RELEASE
     char   *temp_string;
     fprintf(stderr, "Begin %s(): \n", __PRETTY_FUNCTION__);
 #endif
@@ -47,7 +49,7 @@ gboolean timer_handler(gpointer data){
     list_time_event_temp = event_time_list;  
     /* get current time */  
     current_time = time(NULL);
-#ifdef PC_EMULATOR    
+#ifndef RELEASE
     temp_string = ctime(&current_time);
     fprintf(stderr,"\nCurrent Time: %s\n",  temp_string);
 /*    g_free(temp_string);*/
@@ -58,6 +60,11 @@ gboolean timer_handler(gpointer data){
 	if(evt->time <= current_time){
 	    switch(evt->type_event){
 		case DAYTIMEEVENT :
+		#ifdef PC_EMULATOR
+		    fprintf(stderr,"DAYTIMEEVENT %s\n",ctime(&evt->time));
+		#endif
+		    g_free(evt);
+                    event_time_list = g_slist_remove(event_time_list, event_time_list->data);
      		    weather_frame_update(FALSE);   
 		break;
 		case DBUSINITEVENT:
@@ -69,17 +76,31 @@ gboolean timer_handler(gpointer data){
 		    weather_initialize_dbus();
 		    /* It is switch off the timer */	
 		    check = g_source_remove(app->timer);
-		    timer (60000);  /* One per minute */
-		break;    
-		default:
-		case AUTOUPDATE:
+		    timer (60000);  /*Reintilize timer One per minute */
+		break;  
+		case UPDATE_AFTER_CONNECTED:
 		    /* delete periodic update */
-		#ifdef PC_EMULATOR
+		#ifndef RELEASE
 		    fprintf(stderr,"Delete evt %s\n",ctime(&evt->time));
 		#endif
 		    g_free(evt);
                     event_time_list = g_slist_remove(event_time_list, event_time_list->data);
-		#ifdef PC_EMULATOR
+		#ifndef RELEASE
+		    fprintf(stderr,"UPDATE by event\n");
+		#endif
+		    app->show_update_window = FALSE;
+		    update_weather();
+    		break;		    
+  
+		default:
+		case AUTOUPDATE:
+		    /* delete periodic update */
+		#ifndef RELEASE
+		    fprintf(stderr,"Delete evt %s\n",ctime(&evt->time));
+		#endif
+		    g_free(evt);
+                    event_time_list = g_slist_remove(event_time_list, event_time_list->data);
+		#ifndef RELEASE
 		    fprintf(stderr,"UPDATE by event\n");
 		#endif
 		    app->show_update_window = FALSE;
@@ -95,7 +116,7 @@ gboolean timer_handler(gpointer data){
     return TRUE;    
 }
 /*******************************************************************************/
-//#ifdef PC_EMULATOR
+#ifndef RELEASE
 /*For debug */
 void print_list(char *buff, size_t buff_size){
     static GSList *list_time_event_temp = NULL;
@@ -120,7 +141,13 @@ void print_list(char *buff, size_t buff_size){
     else
 	fprintf(stderr, tmp);
 }
-//#endif
+#endif
+/*******************************************************************************/
+void create_timer_with_interval(guint interval){
+    app->timer = g_timeout_add(interval,
+			       (GtkFunction)timer_handler,
+			       NULL); /* One per minute */
+}
 /*******************************************************************************/
 void timer(int interval){
     app->timer = g_timeout_add(interval,
@@ -133,7 +160,7 @@ void free_list_time_event(void){
     static GSList *list_time_event_temp = NULL;
     struct event_time *evt;
     
-    #ifdef PC_EMULATOR
+    #ifndef RELEASE
     fprintf(stderr,"Free ALL in list\n");
     print_list(NULL, 0);
     #endif
@@ -141,7 +168,7 @@ void free_list_time_event(void){
 	return;
     list_time_event_temp = event_time_list; 
     while(list_time_event_temp != NULL){
-        #ifdef PC_EMULATOR
+        #ifndef RELEASE
 	fprintf(stderr,"delete\n");
 	#endif
 	evt = list_time_event_temp->data;
@@ -151,7 +178,7 @@ void free_list_time_event(void){
     }
     g_slist_free(event_time_list);
     event_time_list = NULL;
-    #ifdef PC_EMULATOR
+    #ifndef RELEASE
     fprintf(stderr,"list clean\n");
     print_list(NULL, 0);
     #endif
@@ -171,15 +198,13 @@ static gint compare_time(gconstpointer a, gconstpointer b){
 void time_event_add(time_t time_value, short type_event){
     struct event_time *evt = NULL;
 
-    #ifdef PC_EMULATOR
-/*     fprintf(stderr,"time_event_add in list\n");
+    #ifndef RELEASE
+    fprintf(stderr,"time_event_add in list\n");
     print_list(NULL, 0); 
-*/    
     #endif
     if( time_value && time_value > time(NULL)){ 
 	evt = g_new0(struct event_time, 1);
-	if (evt != NULL) 
-	{
+	if (evt != NULL){
 	    evt->time = time_value;	  
 	    evt->type_event = type_event;
 	    event_time_list = g_slist_insert_sorted(event_time_list,evt,compare_time);
@@ -187,37 +212,58 @@ void time_event_add(time_t time_value, short type_event){
 	else
 	    fprintf(stderr,"evt NULL\n");
     }
-    #ifdef PC_EMULATOR
-/*     fprintf(stderr,"time_event_add in list finished\n");
-     print_list(NULL, 0); 
-*/     
+    #ifndef RELEASE
+    fprintf(stderr,"time_event_add in list finished\n");
+    print_list(NULL, 0);
     #endif
 }
 /*******************************************************************************/
-/* Add periodic time event  to list */	  
+/*  Addition the periodic time in the list of events  for weather forecast updating */	  
 void add_periodic_event(time_t last_update){
 
-    #ifdef PC_EMULATOR
+    #ifndef RELEASE
     fprintf(stderr,"Add in list\n");
     print_list(NULL, 0);
     #endif
 
-    if(app->update_interval > 0)
-	time_event_add(last_update + app->update_interval * 60, AUTOUPDATE);
+    if(app->config->update_interval > 0)
+	time_event_add(last_update + app->config->update_interval * 60, AUTOUPDATE);
 
-    #ifdef PC_EMULATOR
+    #ifndef RELEASE
     fprintf(stderr,"Item added to list\n");
     print_list(NULL, 0);
     #endif
 	
 }
+/*******************************************************************************/
+/* Addition the current time in the list of events  for weather forecast updating */	  
+void add_current_time_event(void){
+
+    time_t current_time;	
+    
+    #ifndef RELEASE
+	fprintf(stderr,"Add in list\n");
+        print_list(NULL, 0);
+    #endif
+    
+    /* get current time */  
+    current_time = time(NULL);
+    time_event_add(current_time + 4 , UPDATE_AFTER_CONNECTED); /* The current time plus 4 seconds */
+    
+    #ifndef RELEASE
+	fprintf(stderr,"Item added to list\n");
+	print_list(NULL, 0);
+    #endif
+	
+}
+
 /*******************************************************************************/
 /* Remove periodic time event  from list */	  
 void remove_periodic_event(void){
     static GSList *list_time_event_temp = NULL;
     struct event_time *evt;
     
-    #ifdef PC_EMULATOR
+    #ifndef RELEASE
     fprintf(stderr,"Periodic remove from list\n");
     print_list(NULL, 0);
     #endif
@@ -235,7 +281,7 @@ void remove_periodic_event(void){
 	list_time_event_temp = g_slist_next(list_time_event_temp);
     }
 
-    #ifdef PC_EMULATOR
+    #ifndef RELEASE
     fprintf(stderr,"Periodic is remove from list\n");
     print_list(NULL, 0);
     #endif
@@ -245,7 +291,7 @@ void remove_daytime_event(void){
     static GSList *list_time_event_temp = NULL;
     struct event_time *evt;
     
-    #ifdef PC_EMULATOR
+    #ifndef RELEASE
     fprintf(stderr,"DAYTIMEEVENT remove from list\n");
     print_list(NULL, 0);
     #endif
@@ -263,7 +309,7 @@ void remove_daytime_event(void){
 	list_time_event_temp = g_slist_next(list_time_event_temp);
     }
 
-    #ifdef PC_EMULATOR
+    #ifndef RELEASE
     fprintf(stderr,"DAYTIMEEVENT is remove from list\n");
     print_list(NULL, 0);
     #endif
