@@ -33,14 +33,17 @@
 /*******************************************************************************/
 #include "weather-home_common.h"
 /*******************************************************************************/
+extern gboolean not_event;
+/*******************************************************************************/
 gboolean timer_handler(gpointer data);
 void timer(int interval);
+void create_timer_with_interval(guint interval);
 void add_periodic_event(time_t last_update);
+void add_current_time_event(void);
 void remove_daytime_event(void);
 void remove_periodic_event(void);
 void print_list(char *buff, size_t buff_size);
 void time_event_add(time_t time_value, short type_event);
-extern gboolean not_event;
 extern void weather_initialize_dbus(void);
 time_t next_update(void);
 /*******************************************************************************/
