@@ -32,9 +32,7 @@
 #include <fcntl.h>
 #include <errno.h>
 /*******************************************************************************/
-/*
- * Change the weather cache directory and update dependent variables.
- */
+/* Change the weather cache directory and update dependent variables. */
 gboolean config_set_weather_dir_name(gchar *new_weather_dir_name){
     GnomeVFSURI *weather_dir_uri;
     gboolean retval = FALSE;
@@ -60,23 +58,14 @@ gboolean config_set_weather_dir_name(gchar *new_weather_dir_name){
     else
 	retval = TRUE;
     if(retval){
-        if(app->weather_dir_name)
-            g_free(app->weather_dir_name);
-        app->weather_dir_name = new_weather_dir_name;
+        if(app->config->cache_dir_name)
+            g_free(app->config->cache_dir_name);
+        app->config->cache_dir_name = new_weather_dir_name;
     }    
     gnome_vfs_uri_unref(weather_dir_uri);
     return retval;
 }
 /*******************************************************************************/
-/* Add time update to list */
-void add_time_update_list(gint _between_time, gchar *_time_name){
-    struct time_update *tu;
-    tu = g_new0(struct time_update, 1);
-    tu->between_time = _between_time;	  
-    tu->name_between_time = g_strdup(_time_name);	  
-    time_update_list = g_slist_append(time_update_list, tu);
-}
-/*******************************************************************************/
 /* The stations data  fill from clock plugin data */
 void fill_station_from_clock_plugin_data(void){
     FILE  *clock_file;  
@@ -89,7 +78,7 @@ void fill_station_from_clock_plugin_data(void){
     GConfClient *gconf_client = gconf_client_get_default();
     /* City name from config file of clock */
     home_city = gconf_client_get_string(gconf_client,
-        			    GCONF_KEY_CLOCK_HOME_LOCATION, NULL);  
+        			    GCONF_KEY_CLOCK_HOME_LOCATION, NULL);
     if(!home_city)
 	return;
     remote_city = gconf_client_get_string(gconf_client,
@@ -98,115 +87,43 @@ void fill_station_from_clock_plugin_data(void){
 	return;
     if((clock_file = fopen(CLOCK_FILE,"r")) != NULL){
 	while(!feof(clock_file)){
-	    memset(out_buffer, 0, sizeof(out_buffer)); /* Clear buffer */
-	    fgets(out_buffer, sizeof(out_buffer), clock_file); /* Read Next Line */
-	    tmp = strchr(out_buffer,'|'); /* Finding of a separator */
-	    if ((strncmp(out_buffer,home_city,tmp-out_buffer)==0) || 
-	        (strncmp(out_buffer,remote_city,tmp-out_buffer)==0))
-	    {
+	    memset(out_buffer, 0, sizeof(out_buffer));
+	    fgets(out_buffer, sizeof(out_buffer) - 1, clock_file);
+	    tmp = strchr(out_buffer, ';'); /* Separator changed from | to ; in 0.19 version */
+	    if(!tmp)
+		tmp = strchr(out_buffer, '|'); /* Finding old separator */
+	    if(!tmp)
+		continue;
+	    if(!strncmp(out_buffer, home_city, tmp - out_buffer) || 
+	        !strncmp(out_buffer, remote_city, tmp - out_buffer)){
 		/* Prepare struct */
     		ws = g_new0(struct weather_station, 1);
-		tmp[strlen(tmp)-1] = 0;
-		ws->id_station = g_strdup(tmp+1);
+		tmp[ strlen(tmp) - 1 ] = 0;
+		ws->id_station = g_strdup(tmp + 1);
 		tmp[0] = 0;
 		ws->name_station = g_strdup(out_buffer);
 		/* Add station to stations list */
-		stations_view_list = g_slist_append(stations_view_list, ws); 
+		app->stations_view_list = g_slist_append(app->stations_view_list, ws); 
 		/* A current station */
-		if (strncmp(out_buffer,home_city,tmp-out_buffer)==0)
-		{
-		    app->current_station_id = g_strdup(ws->id_station);
-		    app->current_station_name = g_strdup(ws->name_station);
+		if(!strncmp(out_buffer, home_city, tmp - out_buffer)){
+		    app->config->current_station_id = g_strdup(ws->id_station);
+		    app->config->current_station_name = g_strdup(ws->name_station);
 		}
 	    }	    
 	}
-	fclose (clock_file);
+	fclose(clock_file);
     }
-    if (home_city)
+    if(home_city)
 	g_free(home_city);
-    if (remote_city)
+    if(remote_city)
 	g_free(remote_city);	
 }
 /*******************************************************************************/
-gboolean fill_station_inform( struct weather_station *ws){
-    FILE *stations_file;  
-    char state_name[21];
-/*  unsigned char out_buffer[1024]; */
-    char out_buffer[1024]; /* buffer for work with stations.txt files*/
-    char temp_station_name[21];
-    char temp_station_code[9];
-    int i;
-    /* Search state or province on country and add stations to combobox*/
-    if((stations_file = fopen(STATIONS_FILE,"r")) != NULL){
-	memset(state_name, 0, sizeof(state_name)); /* Clear temporary value */
-	while(!feof(stations_file)){
-	    memset(out_buffer, 0, sizeof(out_buffer)); /* Clear buffer */
-	    fgets(out_buffer, sizeof(out_buffer), stations_file); /* Read Next Line */
-	    memset(temp_station_name, 0, sizeof(temp_station_name)); /* Clear buffer */
-	    if( (strlen(out_buffer) > 27) && ((char)out_buffer[0] != '!') ){ /* Is it country or state or province name ? */
-    		if( out_buffer[19] != ' ' )
-		    sprintf(state_name,"%.19s",out_buffer);
-	/* Check for wrong string */ 
-		if( strlen(out_buffer) > 90 ){
-	  /* Prepare strings station_name and code_name for work */
-		    for(i = 3; i < 19; i++)
-			temp_station_name[i - 3] = out_buffer[i];
-		    for(i = 84; i < 92; i++)
-			temp_station_code[i - 84] = out_buffer[i];
-		    temp_station_code[8] = 0;
-	  /* Trim right space */
-    		    for(i = 15; i > 0; i--)
-    			if(temp_station_name[i] == ' ')
-        		    temp_station_name[i] = 0;
-    			else
-        		    break;
-		    if( strcmp(ws->id_station,temp_station_code) == 0 ){
-			ws->name_station = g_strdup(temp_station_name);	   
-			fclose(stations_file);  
-			return TRUE;
-		    } 
-		}    	  
-	    } 
-	}
-	fclose(stations_file);  
-    }
-    return FALSE;    
-}
-/*******************************************************************************/
-/* Reinitialize stations list */
-void reinitilize_stations_list(gchar *stations_string){
-    struct weather_station *ws;
-    gchar	*temp1 = NULL,
-		*temp2 = NULL;
-
-    stations_view_list = NULL; /* Initialize value */
-    temp1 = g_strdup(stations_string);
- /* Delimit stations Id string */
-    if(strlen(temp1) > 0){
-	temp2 = strtok(temp1, "@\0"); /* Delimiter between ID - @ */
-	if(temp2)  /* Check random error */      
-	    do{
-		if(strlen(temp2) > 0){
-		    ws = g_new0(struct weather_station, 1);
-		    ws->id_station = g_strdup(temp2);
-		    if(fill_station_inform(ws))
-			stations_view_list = g_slist_append(stations_view_list, ws); /* Add station to stations list */
-		    else{
-			g_free(ws->id_station);
-			g_free(ws);
-		    }
-		}
-		temp2 = strtok(NULL, "@\0"); /* Delimiter between ID - @ */
-	    }while(temp2);
-    }
-    g_free(temp1);       
-}
-/*******************************************************************************/
 /* New Reinitialize stations list */
 void reinitilize_stations_list2(GSList *stlist){
     struct weather_station *ws = NULL;
     gchar *temp1 = NULL, *temp2 = NULL;
-    stations_view_list = NULL; /* Initialize value */
+    app->stations_view_list = NULL; /* Initialize value */
 
     while(stlist != NULL){
 	temp1 = strdup(stlist->data);
@@ -221,7 +138,7 @@ void reinitilize_stations_list2(GSList *stlist){
 	    temp2 = strtok(NULL,"@\0"); /* Delimiter between ID - @ */ 
 	    if(temp2 != NULL)
 		ws->name_station = g_strdup(temp2); 
-	    stations_view_list = g_slist_append(stations_view_list, ws); /* Add station to stations list */
+	    app->stations_view_list = g_slist_append(app->stations_view_list, ws); /* Add station to stations list */
 	}     
 	g_free(stlist->data);      
 	g_free(temp1);
@@ -229,24 +146,6 @@ void reinitilize_stations_list2(GSList *stlist){
     }	    
 }
 /*******************************************************************************/
-/* Prepare stations ID list in one string to write config file */
-gchar* prepare_idlist_string(void){
-    GString *result_string;
-    GSList *tmplist = NULL;
-    struct weather_station *ws;
-
-   /* Initialize value */
-    tmplist = stations_view_list;
-    result_string = g_string_new(NULL);
-    while(tmplist != NULL){
-	ws = tmplist->data;
-	g_string_append(result_string, ws->id_station);
-	g_string_append_c(result_string,'@'); /* @ - delimiter */
-	tmplist = g_slist_next(tmplist);
-    }      
-    return g_string_free(result_string, FALSE);
-}
-/*******************************************************************************/
 /* Prepare stations ID list  to write config file */
 GSList* prepare_idlist(void){
     GSList *stlist = NULL;
@@ -254,7 +153,7 @@ GSList* prepare_idlist(void){
     struct weather_station *ws;
     char *str;
 
-    tmplist = stations_view_list;
+    tmplist = app->stations_view_list;
     while(tmplist != NULL){ 
 	ws = tmplist->data;
 	str = g_strdup_printf("%s@%s", ws->id_station, ws->name_station);
@@ -264,37 +163,81 @@ GSList* prepare_idlist(void){
     return stlist;
 }
 /*******************************************************************************/
-/* Initialize all configuration from GCONF.  This should not be called more
- * than once during execution. */
-void read_config(void){
-    gchar	*tmp = NULL;
+GtkListStore* create_time_update_list(void){
+    GtkListStore	*list = NULL;
+    GtkTreeIter         iter;
+
+    list = gtk_list_store_new(3, G_TYPE_STRING, G_TYPE_INT, G_TYPE_INT);
+    
+    gtk_list_store_append(list, &iter);
+    gtk_list_store_set(list, &iter, 0, _("Never"), 1, 0, 2, 0, -1);
+    gtk_list_store_append(list, &iter);
+    gtk_list_store_set(list, &iter, 0, _("every 5 minutes"), 1, 5, 2, 0, -1);
+    gtk_list_store_append(list, &iter);
+    gtk_list_store_set(list, &iter, 0, _("every 30 minutes"), 1, 30, 2, 0, -1);
+    gtk_list_store_append(list, &iter);
+    gtk_list_store_set(list, &iter, 0, _("every hour"), 1, 60, 2, 0, -1);
+    gtk_list_store_append(list, &iter);
+    gtk_list_store_set(list, &iter, 0, _("every 2 hours"), 1, 120, 2, 0, -1);
+    gtk_list_store_append(list, &iter);
+    gtk_list_store_set(list, &iter, 0, _("every 4 hours"), 1, 240, 2, 0, -1);
+    gtk_list_store_append(list, &iter);
+    gtk_list_store_set(list, &iter, 0, _("every 8 hours"), 1, 480, 2, 0, -1);
+    gtk_list_store_append(list, &iter);
+    gtk_list_store_set(list, &iter, 0, _("every 24 hours"), 1, 1440, 2, 0, -1);
+    gtk_list_store_append(list, &iter);
+    gtk_list_store_set(list, &iter, 0, _("every minute (Debug)"), 1, 1, 2, 0, -1);
+
+    return list;
+}
+/*******************************************************************************/
+int new_read_config(AppletConfig *config){
     GConfValue	*value = NULL;
     GConfClient *gconf_client = NULL;
     int		fd = -1;
     GSList	*stlist = NULL;
     GError	*gerror = NULL;
-    GdkColor	DEFAULT_FONT_COLOR = {0, 0x0d00, 0x2a00, 0xc000};
+    GdkColor	DEFAULT_FONT_COLOR = {0, 0xFF00, 0xFF00, 0x0000};
+    gchar	tmp_buff[1024],
+		*home_dir,
+		*tmp = NULL;
+
+#ifndef RELEASE
+    fprintf(stderr,"BEGIN %s(): \n", __PRETTY_FUNCTION__);
+#endif
 
-    
     gconf_client = gconf_client_get_default();
 
     if(!gconf_client){
         fprintf(stderr, _("Failed to initialize GConf. Quitting.\n"));
-        exit(1);
+        return 1;
     }
     /* Get Weather Cache Directory.  Default is "~/apps/omweather". */
     tmp = gconf_client_get_string(gconf_client,
         			    GCONF_KEY_WEATHER_DIR_NAME, NULL);
-    if(!tmp)
-        tmp = g_strdup("~/apps/omweather");
-    if(!config_set_weather_dir_name(gnome_vfs_expand_initial_tilde(tmp)))
-        fprintf(stderr, _("Could not create Weather Cache directory.\n"));
-    g_free(tmp);
+    if(!tmp){
+	home_dir = getenv("HOME");
+	if(!home_dir){
+    	    fprintf(stderr, _("Can not get path to the HOME directory. Quitting.\n"));
+    	    return 1;
+	}
+	memset(tmp_buff, 0, sizeof(tmp_buff));
+	snprintf(tmp_buff, sizeof(tmp_buff) - 1, "%s%s",
+		    home_dir, "/apps/omweather");
+	home_dir = NULL;
+    }
+    else
+	snprintf(tmp_buff, sizeof(tmp_buff) - 1, "%s", tmp);
+    config->cache_directory = g_strdup(tmp);
+    if(tmp)
+	g_free(tmp);
     tmp = NULL;
+
+    if(!config_set_weather_dir_name(gnome_vfs_expand_initial_tilde(tmp_buff)))
+        fprintf(stderr, _("Could not create Weather Cache directory.\n"));
     /* Get Weather Station ID for current station */
-    app->current_station_id = gconf_client_get_string(gconf_client,
+    config->current_station_id = gconf_client_get_string(gconf_client,
         			    GCONF_KEY_WEATHER_CURRENT_STATION_ID, NULL);
-    
     /* Get Weather Stations ID and NAME */
     stlist = gconf_client_get_list(gconf_client,
         			    GCONF_KEY_WEATHER_STATIONS_LIST,
@@ -304,222 +247,214 @@ void read_config(void){
 	g_slist_free(stlist);
     }
     /* Get icon set name */ 
-    app->icon_set = gconf_client_get_string(gconf_client,
+    config->icon_set = gconf_client_get_string(gconf_client,
 					    GCONF_KEY_WEATHER_ICON_SET,
 					    NULL);
-    sprintf(path_large_icon, "%s%s/", ICONS_PATH, app->icon_set);
+    sprintf(path_large_icon, "%s%s/", ICONS_PATH, config->icon_set);
     if( ( fd = open(path_large_icon, O_RDONLY) ) == -1 ){
 	memset(path_large_icon, 0, sizeof(path_large_icon));
-	app->icon_set = g_strdup("Crystal");
-	sprintf(path_large_icon, "%s%s/", ICONS_PATH, app->icon_set);
+	config->icon_set = g_strdup("Crystal");
+	sprintf(path_large_icon, "%s%s/", ICONS_PATH, config->icon_set);
     }
     else
 	close(fd);
-	
     /* Get Weather Icon Size  */		     
-    app->icons_size = gconf_client_get_int(gconf_client,
+    config->icons_size = gconf_client_get_int(gconf_client,
         				    GCONF_KEY_WEATHER_ICONS_SIZE,
 					    NULL);
-    if(app->icons_size < 0 || app->icons_size < LARGE || app->icons_size > SMALL)
-        app->icons_size = LARGE;
-	
+    if(config->icons_size < LARGE || config->icons_size > SMALL)
+        config->icons_size = LARGE;
+
+    /* Get setting tab number  */		     
+    config->current_settings_page = gconf_client_get_int(gconf_client,
+        				    GCONF_KEY_WEATHER_SETTING_TAB_NUMBER,
+					    NULL);
+    if(config->current_settings_page < 0 ||
+	config->current_settings_page > MAX_SETTINGS_PAGE_NUMBER)
+        config->current_settings_page = 0;
+
     /* Get Weather country name. */    
-    app->current_country = gconf_client_get_string(gconf_client,
+    config->current_country = gconf_client_get_string(gconf_client,
         					    GCONF_KEY_WEATHER_CURRENT_COUNTRY_NAME,
 						    NULL);
     /* Get Weather station name. */
-    app->current_station_name = gconf_client_get_string(gconf_client,
+    config->current_station_name = gconf_client_get_string(gconf_client,
     							GCONF_KEY_WEATHER_CURRENT_STATION_NAME,
 							NULL);
-    /* Get Weather periodic update time . */
-    app->update_interval = gconf_client_get_int(gconf_client,
+    /* Get Weather periodic update time. */
+    config->update_interval = gconf_client_get_int(gconf_client,
         			    GCONF_KEY_WEATHER_UPDATE_INTERVAL,
 				    NULL);
-    if(app->update_interval < 0 || app->update_interval > 24 * 60) /* No more than 24 hours */
-	app->update_interval = 0;
+    if(config->update_interval < 0 || config->update_interval > 24 * 60 ) /* No more than 24 hours */
+	config->update_interval = 0;
+    remove_periodic_event();		/* delete event from list */
+    add_periodic_event(time(NULL));	/* add new event */
+
     /* Get Weather font color. */    	
     tmp = gconf_client_get_string(gconf_client,
         			    GCONF_KEY_WEATHER_FONT_COLOR, NULL);
-    if(!tmp || !gdk_color_parse(tmp, &(app->font_color)))
-         app->font_color = DEFAULT_FONT_COLOR; 
+    if(!tmp || !gdk_color_parse(tmp, &(config->font_color)))
+         config->font_color = DEFAULT_FONT_COLOR; 
     g_free(tmp);
     tmp = NULL;
+
+    /* Get background color. */    	
+    tmp = gconf_client_get_string(gconf_client,
+        			    GCONF_KEY_WEATHER_BACKGROUND_COLOR, NULL);
+    if(!tmp || !gdk_color_parse(tmp, &(config->background_color)))
+         config->background_color = DEFAULT_FONT_COLOR; 
+    g_free(tmp);
+    tmp = NULL;
+
     /* Get Enable Transparency flag. Default is TRUE. */
     value = gconf_client_get(gconf_client, GCONF_KEY_ENABLE_TRANSPARENCY, NULL);
     if(value){
-        app->transparency = gconf_value_get_bool(value);
+        config->transparency = gconf_value_get_bool(value);
         gconf_value_free(value);
     }
     else
-        app->transparency = TRUE;      
+        config->transparency = TRUE;
     /* Get Split Button State. Default is FALSE */
     value = gconf_client_get(gconf_client, GCONF_KEY_SEPARATE_DATA, NULL);
     if(value){
-        app->separate = gconf_value_get_bool(value);
+        config->separate = gconf_value_get_bool(value);
         gconf_value_free(value);
     }
     else
-        app->separate = FALSE;      	
+        config->separate = FALSE;
+
+    /* Get auto_downloading_after_connecting. Default is FALSE */
+    value = gconf_client_get(gconf_client, GCONF_KEY_DOWNLOADING_AFTER_CONNECTING, NULL);
+    if(value){
+        config->downloading_after_connecting = gconf_value_get_bool(value);
+        gconf_value_free(value);
+    }
+    else
+        config->downloading_after_connecting = FALSE;
+
+    
     /* Get Swap Temperature Button State. Default is FALSE */
     value = gconf_client_get(gconf_client, GCONF_KEY_SWAP_TEMPERATURE, NULL);
     if(value){
-        app->swap_hi_low_temperature = gconf_value_get_bool(value);
+        config->swap_hi_low_temperature = gconf_value_get_bool(value);
         gconf_value_free(value);
     }
     else
-        app->swap_hi_low_temperature = FALSE;      	
-	
+        config->swap_hi_low_temperature = FALSE;
+
+    /* Get Hide Station State. Default is FALSE */
+    value = gconf_client_get(gconf_client, GCONF_KEY_HIDE_STATION_NAME, NULL);
+    if(value){
+        config->hide_station_name = gconf_value_get_bool(value);
+        gconf_value_free(value);
+    }
+    else
+        config->hide_station_name = FALSE;
+
     /* Get Temperature Unit  Default Celsius */
-    app->temperature_units = gconf_client_get_int(gconf_client,
+    config->temperature_units = gconf_client_get_int(gconf_client,
                     			GCONF_KEY_WEATHER_TEMPERATURE_UNIT, &gerror);
-    (app->temperature_units) ? (app->temperature_units = FAHRENHEIT)
-				: (app->temperature_units = CELSIUS);
-    /* Get Temperature Unit  Default Celsius */
-    /* Depricated, after 0.18 not used */
+    (config->temperature_units) ? (config->temperature_units = FAHRENHEIT)
+				: (config->temperature_units = CELSIUS);
     if(gerror){
-        tmp = gconf_client_get_string(gconf_client,
-                     GCONF_KEY_WEATHER_TEMPERATURE_UNIT, NULL);
-	if(tmp){
-	    if(tmp[0] == 'C')
-		app->temperature_units = CELSIUS;
-	    else
-		app->temperature_units = FAHRENHEIT;
-	    g_free(tmp);
-	}
-	else
-	    app->temperature_units = CELSIUS;	  
-	g_error_free(gerror);
+    	g_error_free(gerror);
 	gerror = NULL;
     }
+
     /* Get Layout  Default Horizontal */
-    app->icons_layout = gconf_client_get_int(gconf_client,
-                			    GCONF_KEY_ICONS_LAYOUT,
-					    NULL);
-    if(app->icons_layout < ONE_ROW || app->icons_layout > TWO_COLUMNS)
-	app->icons_layout = ONE_ROW;
-    /* Get number days to show */
-    app->days_to_show = gconf_client_get_int(gconf_client,                                                                                     
-                	    GCONF_KEY_WEATHER_DAYS, &gerror);
-    if(gerror || app->days_to_show <= 0 || app->days_to_show > Max_count_weather_day){
-	app->days_to_show = 5;/* default value */
+    config->icons_layout = gconf_client_get_int(gconf_client,
+                				GCONF_KEY_ICONS_LAYOUT,
+						NULL);
+    if(config->icons_layout < ONE_ROW ||
+	config->icons_layout > TWO_COLUMNS)
+	config->icons_layout = ONE_ROW;
+
+    /* Get number days to show default 5 */
+    config->days_to_show = gconf_client_get_int(gconf_client,                                                                                     
+                				GCONF_KEY_WEATHER_DAYS,
+						&gerror);
+    if(gerror || config->days_to_show <= 0
+	      || config->days_to_show > Max_count_weather_day){
+	config->days_to_show = 5;
+	g_error_free(gerror);
+    }
+    config->previos_days_to_show = config->days_to_show;
+
+    /* Get distance units */
+    config->distance_units = gconf_client_get_int(gconf_client,                                                                                     
+                				    GCONF_KEY_WEATHER_DISTANCE_UNITS,
+						    &gerror);
+    if(gerror || config->distance_units > SEA_MILES){
+	config->distance_units = METERS;
 	g_error_free(gerror);
     }
 
-    app->previos_days_to_show = app->days_to_show;
-    /* Get distance units */
-    app->distance_units = gconf_client_get_int(gconf_client,                                                                                     
-                	    GCONF_KEY_WEATHER_DISTANCE_UNITS, &gerror);
-    if(gerror || app->distance_units < METERS || app->distance_units > SEA_MILES){
-	app->distance_units = METERS;
-	g_error_free(gerror);
-    }
     /* Get wind units */
-    app->wind_units = gconf_client_get_int(gconf_client,                                                                                     
-			GCONF_KEY_WEATHER_WIND_UNITS, &gerror);
-    if(gerror || app->wind_units < METERS_S || app->wind_units > MILES_H){
-	app->wind_units = METERS_S;
+    config->wind_units = gconf_client_get_int(gconf_client,                                                                                     
+						GCONF_KEY_WEATHER_WIND_UNITS,
+						&gerror);
+    if(gerror || config->wind_units > MILES_H){
+	config->wind_units = METERS_S;
 	g_error_free(gerror);
     }
+
     /* Get valid data time for current weather */
-    app->data_valid_interval = gconf_client_get_int(gconf_client,                                                                                     
-			GCONF_KEY_WEATHER_VALID_DATA_TIME, &gerror);
-    if(gerror || (app->data_valid_interval != 1 &&
-		    app->data_valid_interval != 2 && 
-		    app->data_valid_interval != 4 &&
-		    app->data_valid_interval != 8) ){
-	app->data_valid_interval = 2 * 3600; /* Default value - 2 hours */
+    config->data_valid_interval =
+	    gconf_client_get_int(gconf_client,
+				    GCONF_KEY_WEATHER_VALID_DATA_TIME,
+				    &gerror);
+    if(gerror || (config->data_valid_interval != 1 && 
+		    config->data_valid_interval != 2 &&
+		    config->data_valid_interval != 4 &&
+		    config->data_valid_interval != 8) ){
+	config->data_valid_interval = 2 * 3600; /* Default value - 2 hours */
 	g_error_free(gerror);
     }
     else
-	app->data_valid_interval *= 3600;
-    
-    /* Check connection */
-    tmp = gconf_client_get_string(gconf_client,
-        			    GCONF_KEY_CURRENT_CONNECTIVITY, NULL);
-    if(tmp){
-        app->iap_connected = TRUE;
-	g_free(tmp);
-    }	
-    else
-	app->iap_connected = FALSE;
-	
-    
+	config->data_valid_interval *= 3600;
+
     /* If this first start then fill default station from clock config */ 
-    tmp =gconf_client_get_string(gconf_client,
-                     GCONF_KEY_WEATHER_PROGRAM_VERSION, NULL);     
-    if (!tmp){
-	if(!app->current_station_id){
+    tmp = gconf_client_get_string(gconf_client,
+                		    GCONF_KEY_WEATHER_PROGRAM_VERSION, NULL);
+    if(!tmp){
+	if(!app->config->current_station_id){
 	    fill_station_from_clock_plugin_data();
-	    if (app->iap_connected){
+	    if(app->iap_connected){
 		app->show_update_window = TRUE;
 		update_weather();
-	    }	
+	    }
 	}	    
     }
     else{
 	g_free(tmp);		     
 	tmp = NULL;		
-    }
-    /* Fill time update list */
-    if(!time_update_list){
-	add_time_update_list(0, _("Never"));
-	add_time_update_list(5, _("every 5 minutes"));
-	add_time_update_list(30, _("every 30 minutes"));
-	add_time_update_list(1 * 60, _("every hour"));
-	add_time_update_list(2 * 60, _("every 2 hours"));
-	add_time_update_list(4 * 60, _("every 4 hours"));
-	add_time_update_list(8 * 60, _("every 8 hours"));
-	add_time_update_list(24 * 60, _("every 24 hours"));
-/* #ifdef PC_EMULATOR */
-	add_time_update_list(1, _("every minute (DEBUG)"));
-/* #endif */
-    }
-    app->show_update_window = FALSE;
+    }    
     gconf_client_clear_cache(gconf_client);
     g_object_unref(gconf_client);
+    return 0;
 }
 /*******************************************************************************/
 void config_update_proxy(void){
     GConfClient *gconf_client = gconf_client_get_default();
-    if(app->iap_http_proxy_host)
-        g_free(app->iap_http_proxy_host);
+    if(app->config->iap_http_proxy_host)
+        g_free(app->config->iap_http_proxy_host);
     /* Get proxy data */
     if(gconf_client_get_bool(gconf_client,
                 GCONF_KEY_HTTP_PROXY_ON, NULL)){
         /* HTTP Proxy is on. */
-        app->iap_http_proxy_host = gconf_client_get_string(gconf_client,
+        app->config->iap_http_proxy_host = gconf_client_get_string(gconf_client,
                 GCONF_KEY_HTTP_PROXY_HOST, NULL);
-        app->iap_http_proxy_port = gconf_client_get_int(gconf_client,
+        app->config->iap_http_proxy_port = gconf_client_get_int(gconf_client,
                 GCONF_KEY_HTTP_PROXY_PORT, NULL);
     }
     else{/* HTTP Proxy is off. */
-        app->iap_http_proxy_host = NULL;
-        app->iap_http_proxy_port = 0;
+        app->config->iap_http_proxy_host = NULL;
+        app->config->iap_http_proxy_port = 0;
     }
     g_object_unref(gconf_client);
 }
-/*******************************************************************************/
-/* Save current station position configuration data to GCONF. */
-void config_save_current_station(){
-    GConfClient *gconf_client = gconf_client_get_default();
-    
-    if(!gconf_client){
-        fprintf(stderr, _("Failed to initialize GConf. Settings were not saved.\n"));
-        return;
-    }
-    /* Save Weather station name. */
-    if(app->current_station_name)
-        gconf_client_set_string(gconf_client,
-            GCONF_KEY_WEATHER_CURRENT_STATION_NAME, app->current_station_name, NULL);
-    /* Save Weather station id. */
-    if(app->current_station_id)
-        gconf_client_set_string(gconf_client,
-            GCONF_KEY_WEATHER_CURRENT_STATION_ID, app->current_station_id, NULL);
-    g_object_unref(gconf_client);
-}
 /*******************************************************************************/ 
-/* Save all configuration data to GCONF. */
-void config_save(){
+void new_config_save(AppletConfig *config){
     gchar temp_buffer[16];
     GConfClient *gconf_client;
     GSList *stlist = NULL;
@@ -535,90 +470,110 @@ void config_save(){
         			GCONF_KEY_WEATHER_PROGRAM_VERSION,
 				VERSION, NULL);
     /* Save Weather Cache Directory. */
-    if(app->weather_dir_name)
+    if(config->cache_dir_name)
         gconf_client_set_string(gconf_client,
         			GCONF_KEY_WEATHER_DIR_NAME,
-				app->weather_dir_name, NULL);
+				config->cache_dir_name, NULL);
     /* Save Weather country name. */
-    if(app->current_country)
+    if(config->current_country)
         gconf_client_set_string(gconf_client,
         			GCONF_KEY_WEATHER_CURRENT_COUNTRY_NAME,
-				app->current_country, NULL);	    
+				config->current_country, NULL);	    
     /* Save Weather station name. */
-    if(app->current_station_name)
+    if(config->current_station_name)
     	gconf_client_set_string(gconf_client,
         			GCONF_KEY_WEATHER_CURRENT_STATION_NAME,
-				app->current_station_name, NULL);
+				config->current_station_name, NULL);
     else	    
         gconf_client_set_string(gconf_client,
         			GCONF_KEY_WEATHER_CURRENT_STATION_NAME,
 				"", NULL);
     /* Save Weather station id. */
-    if(app->current_station_id)
+    if(config->current_station_id)
         gconf_client_set_string(gconf_client,
         			GCONF_KEY_WEATHER_CURRENT_STATION_ID,
-				app->current_station_id, NULL);
+				config->current_station_id, NULL);
     else 	    
         gconf_client_set_string(gconf_client,
         			GCONF_KEY_WEATHER_CURRENT_STATION_ID,
 				"", NULL);
     /* Save icon set name */
-    if(app->icon_set)
+    if(config->icon_set)
 	gconf_client_set_string(gconf_client,
 				GCONF_KEY_WEATHER_ICON_SET,
-				app->icon_set, NULL);
+				config->icon_set, NULL);
     /* Save Weather Icon Size  */		     	    
     gconf_client_set_int(gconf_client,
         		GCONF_KEY_WEATHER_ICONS_SIZE,
-			app->icons_size, NULL);
+			config->icons_size, NULL);
+    /* Save current setting tab number  */		     	    
+    gconf_client_set_int(gconf_client,
+        		GCONF_KEY_WEATHER_SETTING_TAB_NUMBER,
+			config->current_settings_page, NULL);
     /* Save Weather Font Color */
     sprintf(temp_buffer, "#%02x%02x%02x",
-            app->font_color.red >> 8,
-            app->font_color.green >> 8,
-            app->font_color.blue >> 8);
+            config->font_color.red >> 8,
+            config->font_color.green >> 8,
+            config->font_color.blue >> 8);
     gconf_client_set_string(gconf_client,
         		    GCONF_KEY_WEATHER_FONT_COLOR,
 			    temp_buffer, NULL);
+    /* Save Background Color */
+    sprintf(temp_buffer, "#%02x%02x%02x",
+            config->background_color.red >> 8,
+            config->background_color.green >> 8,
+            config->background_color.blue >> 8);
+    gconf_client_set_string(gconf_client,
+        		    GCONF_KEY_WEATHER_BACKGROUND_COLOR,
+			    temp_buffer, NULL);
     /* Save Weather Update setting  */
     gconf_client_set_int(gconf_client,
         		    GCONF_KEY_WEATHER_UPDATE_INTERVAL,
-			    app->update_interval, NULL);
+			    config->update_interval, NULL);
      /* Save Enable Enable Transparency flag. */
     gconf_client_set_bool(gconf_client,
         		GCONF_KEY_ENABLE_TRANSPARENCY,
-			app->transparency, NULL);
+			config->transparency, NULL);
      /* Save Split Button State */
     gconf_client_set_bool(gconf_client,
         		GCONF_KEY_SEPARATE_DATA,
-			app->separate, NULL);	    
+			config->separate, NULL);	    
+     /* Save Downloading after connecting State */
+    gconf_client_set_bool(gconf_client,
+        		GCONF_KEY_DOWNLOADING_AFTER_CONNECTING,
+			config->downloading_after_connecting, NULL);	    
      /* Save Swap Temperature Button State */
     gconf_client_set_bool(gconf_client,
         		GCONF_KEY_SWAP_TEMPERATURE,
-			app->swap_hi_low_temperature, NULL);	    
+			config->swap_hi_low_temperature, NULL);	    
+     /* Hide Station Name and Arrows */
+    gconf_client_set_bool(gconf_client,
+        		GCONF_KEY_HIDE_STATION_NAME,
+			config->hide_station_name, NULL);
     /* Save Weather Temperature Unit  */		     	    
     gconf_client_set_int(gconf_client,
         		GCONF_KEY_WEATHER_TEMPERATURE_UNIT,
-			app->temperature_units, NULL);
+			config->temperature_units, NULL);
     /* Save Days to show. */
     gconf_client_set_int(gconf_client,
         		GCONF_KEY_WEATHER_DAYS,
-			app->days_to_show, NULL);	    
+			config->days_to_show, NULL);	    
     /* Save distance units. */
     gconf_client_set_int(gconf_client,
         		GCONF_KEY_WEATHER_DISTANCE_UNITS,
-			app->distance_units, NULL);
+			config->distance_units, NULL);
     /* Save wind units. */
     gconf_client_set_int(gconf_client,
         		GCONF_KEY_WEATHER_WIND_UNITS,
-			app->wind_units, NULL);
+			config->wind_units, NULL);
     /* Save valid data time */
     gconf_client_set_int(gconf_client,
         		GCONF_KEY_WEATHER_VALID_DATA_TIME,
-			app->data_valid_interval / 3600, NULL);
+			config->data_valid_interval / 3600, NULL);
     /* Save Layout type. */
     gconf_client_set_int(gconf_client,
         		GCONF_KEY_ICONS_LAYOUT,
-			app->icons_layout, NULL);	    
+			config->icons_layout, NULL);	    
     /* Save station list */
     stlist = prepare_idlist();
     gconf_client_set_list(gconf_client,
@@ -628,5 +583,4 @@ void config_save(){
     g_slist_foreach(stlist, (GFunc)g_free, NULL);
     g_slist_free(stlist);
     g_object_unref(gconf_client);
-}
-/*******************************************************************************/
+}/*******************************************************************************/
