@@ -32,31 +32,28 @@
 /*******************************************************************************/
 #include "weather-home_common.h"
 #include <curl/multi.h>
+
+#ifdef USE_DBUS
 #include <osso-ic.h>
 #include <osso-ic-dbus.h>
+#include <dbus/dbus.h>
+#endif
+
 #include <dbus/dbus-glib.h>
 /*******************************************************************************/
-static GString *url = NULL;
-static GString *full_filename_new_xml = NULL;
-CURL *curl_handle = NULL;
-CURL *curl_multi = NULL;
 CURL* weather_curl_init(CURL *curl_handle);
 gboolean download_html(gpointer data);
 void weather_initialize_dbus(void);
 gboolean check_connected(void);
 void clean_download(void);
-GtkWidget *update_window = NULL;     
 /*******************************************************************************/
 struct HtmlFile {
   char *filename;
   FILE *stream;
 };
 /*******************************************************************************/
-struct HtmlFile html_file;
-gint num_transfers = 0, num_msgs = 0;
-GSList *tmplist = NULL;
-struct weather_station *ws;
-gboolean second_attempt=FALSE;
 extern void config_update_proxy(void);
+extern void add_current_time_event(void);
+extern void popup_window_destroy(void);
 /*******************************************************************************/
 #endif
